@@ -4,7 +4,7 @@
  *
  * @section LICENSE
  *
- *      Copyright 2009 - 2013 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -54,7 +54,7 @@ ArpWidget::ArpWidget(MidiArp *p_midiWorker, GlobStore *p_globStore,
     modified(false)
 {
     midiControl = new MidiControl(this);
-    manageBox = new ManageBox("Arp:", true, this);
+    manageBox = new ManageBox("Arp:", false, this);
 #else
 ArpWidget::ArpWidget(
     bool compactStyle,
@@ -210,7 +210,7 @@ ArpWidget::ArpWidget(
     QVBoxLayout *patternBoxLayout = new QVBoxLayout;
 
     textEditButton = new QToolButton(this);
-    textEditAction = new QAction(QIcon(editmodeon_xpm),
+    textEditAction = new QAction(QPixmap(editmodeon_xpm),
             tr("&Edit Pattern"), this);
     connect(textEditAction, SIGNAL(toggled(bool)), this,
             SLOT(openTextEditWindow(bool)));
@@ -219,7 +219,7 @@ ArpWidget::ArpWidget(
 
 #ifdef APPBUILD
     textRemoveButton = new QToolButton(this);
-    textRemoveAction = new QAction(QIcon(patternremove_xpm),
+    textRemoveAction = new QAction(QPixmap(patternremove_xpm),
             tr("&Remove Pattern"), this);
     connect(textRemoveAction, SIGNAL(triggered()), this,
             SLOT(removeCurrentPattern()));
@@ -227,7 +227,7 @@ ArpWidget::ArpWidget(
     textRemoveAction->setEnabled(false);
 
     textStoreButton = new QToolButton(this);
-    textStoreAction = new QAction(QIcon(patternstore_xpm),
+    textStoreAction = new QAction(QPixmap(patternstore_xpm),
             tr("&Store Pattern"), this);
     connect(textStoreAction, SIGNAL(triggered()), this,
             SLOT(storeCurrentPattern()));
@@ -270,13 +270,34 @@ ArpWidget::ArpWidget(
     QStringList repeatPatternNames;
     repeatPatternNames << tr("Static") << tr("Up") << tr("Down") << tr("Random");
     repeatPatternThroughChord->insertItems(0, repeatPatternNames);
-    repeatPatternThroughChord->setToolTip(tr("Repeat mode"));
+    repeatPatternThroughChord->setToolTip(tr("Repeat mode - This is how notes are sequenced\n"
+                            "when a chord is pressed"));
     connect(repeatPatternThroughChord, SIGNAL(currentIndexChanged(int)), this,
             SLOT(updateRepeatPattern(int)));
     repeatPatternThroughChord->setCurrentIndex(1);
 
+    octaveModeBox = new QComboBox(patternBox);
+    repeatPatternNames.clear();
+    repeatPatternNames << tr("Static") << tr("Up") << tr("Down") << tr("Bounce");
+    octaveModeBox->insertItems(0, repeatPatternNames);
+    octaveModeBox->setToolTip(tr("Octave mode - The overall octave changes like this\n"
+                            "once all pressed notes were played through"));
+    connect(octaveModeBox, SIGNAL(currentIndexChanged(int)), this,
+            SLOT(updateOctaveMode(int)));
+    octaveModeBox->setCurrentIndex(0);
+
+    octaveRangeBox = new QComboBox(patternBox);
+    repeatPatternNames.clear();
+    repeatPatternNames << "1" << "2" << "3";
+    octaveRangeBox->insertItems(0, repeatPatternNames);
+    octaveRangeBox->setToolTip(tr("Octave range - the range above and below the played note\n"
+                            "if Octave mode is not static"));
+    connect(octaveRangeBox, SIGNAL(currentIndexChanged(int)), this,
+            SLOT(updateOctaveRange(int)));
+    octaveRangeBox->setCurrentIndex(0);
+
     latchModeButton = new QToolButton(this);
-    latchModeAction = new QAction(QIcon(latchmodeon_xpm),
+    latchModeAction = new QAction(QPixmap(latchmodeon_xpm),
             tr("&Latch Mode"), this);
     connect(latchModeAction, SIGNAL(toggled(bool)), this,
             SLOT(setLatchMode(bool)));
@@ -305,6 +326,8 @@ ArpWidget::ArpWidget(
     modeLayout->addWidget(muteOut);
     modeLayout->addWidget(deferChangesButton);
     modeLayout->addWidget(repeatPatternThroughChord);
+    modeLayout->addWidget(octaveModeBox);
+    modeLayout->addWidget(octaveRangeBox);
     modeLayout->addWidget(latchModeButton);
     modeLayout->addStretch(2);
 
@@ -446,6 +469,10 @@ void ArpWidget::writeData(QXmlStreamWriter& xml)
             xml.writeTextElement("pattern", midiWorker->pattern);
             xml.writeTextElement("repeatMode", QString::number(
                 midiWorker->repeatPatternThroughChord));
+            xml.writeTextElement("octaveMode", QString::number(
+                midiWorker->octMode));
+            xml.writeTextElement("octaveRange", QString::number(
+                midiWorker->octRange));
             xml.writeTextElement("latchMode", QString::number(
                 latchModeAction->isChecked()));
         xml.writeEndElement();
@@ -521,6 +548,10 @@ void ArpWidget::readData(QXmlStreamReader& xml)
                     patternText->setText(xml.readElementText());
                 else if (xml.name() == "repeatMode")
                     repeatPatternThroughChord->setCurrentIndex(xml.readElementText().toInt());
+                else if (xml.name() == "octaveMode")
+                    octaveModeBox->setCurrentIndex(xml.readElementText().toInt());
+                else if (xml.name() == "octaveRange")
+                    octaveRangeBox->setCurrentIndex(xml.readElementText().toInt() - 1);
                 else if (xml.name() == "latchMode")
                     latchModeAction->setChecked(xml.readElementText().toInt());
                 else skipXmlElement(xml);
@@ -716,7 +747,9 @@ void ArpWidget::loadPatternPresets()
 
     if (!f.open(QIODevice::ReadOnly)) {
         QMessageBox::warning(this, PACKAGE,
-                tr("Could not read from resource file"));
+                tr("Could not read the pattern presets from the \n"
+                   ".qmidiarprc resource file. To create this file \n"
+                    "please just run the qmidiarp main application once."));
         return;
     }
     QTextStream loadText(&f);
@@ -742,6 +775,18 @@ void ArpWidget::updateRepeatPattern(int val)
     modified = true;
 }
 
+void ArpWidget::updateOctaveMode(int val)
+{
+    if (midiWorker) midiWorker->updateOctaveMode(val);
+    modified = true;
+}
+
+void ArpWidget::updateOctaveRange(int val)
+{
+    if (midiWorker) midiWorker->octRange = val + 1;
+    modified = true;
+}
+
 void ArpWidget::updateEnableRestartByKbd(bool on)
 {
     if (midiWorker) midiWorker->restartByKbd = on;
