@@ -4,7 +4,7 @@
  *
  * @section LICENSE
  *
- *      Copyright 2009 - 2013 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -31,7 +31,7 @@
 #include "engine.h"
 
 
-Engine::Engine(GlobStore *p_globStore, GrooveWidget *p_grooveWidget, int p_portCount, bool p_alsamidi, QWidget *parent) : QThread(parent), modified(false)
+Engine::Engine(GlobStore *p_globStore, GrooveWidget *p_grooveWidget, int p_portCount, bool p_alsamidi, QWidget *parent) : QObject(parent), modified(false)
 {
     ready = false;
 
@@ -486,7 +486,6 @@ void Engine::echoCallback(bool echo_from_trig)
     int outport;
     int frameptr;
     int percent;
-    bool isNew;
     bool restoreFlag = (restoreRequest >= 0);
     MidiEvent outEv;
 
@@ -594,17 +593,15 @@ void Engine::echoCallback(bool echo_from_trig)
                     note_tick = midiArp(l1)->returnTick;
                     length = midiArp(l1)->returnLength * 4;
                     outport = midiArp(l1)->portOut;
-                    isNew = midiArp(l1)->returnIsNew;
                     arpWidget(l1)->screen->updateScreen(midiArp(l1)->getGrooveIndex());
-                    if (!midiArp(l1)->returnNote.isEmpty()) {
-                        if (isNew && midiArp(l1)->returnVelocity.at(0)) {
-                            l2 = 0;
-                            while(midiArp(l1)->returnNote.at(l2) >= 0) {
-                                outEv.data = midiArp(l1)->returnNote.at(l2);
-                                outEv.value = midiArp(l1)->returnVelocity.at(l2);
-                                driver->sendMidiEvent(outEv, note_tick, outport, length);
-                                l2++;
-                            }
+                    if (midiArp(l1)->hasNewNotes && !midiArp(l1)->returnNote.isEmpty()
+                        && midiArp(l1)->returnVelocity.at(0)) {
+                        l2 = 0;
+                        while(midiArp(l1)->returnNote.at(l2) >= 0) {
+                            outEv.data = midiArp(l1)->returnNote.at(l2);
+                            outEv.value = midiArp(l1)->returnVelocity.at(l2);
+                            driver->sendMidiEvent(outEv, note_tick, outport, length);
+                            l2++;
                         }
                     }
                     frameptr = midiArp(l1)->getGrooveIndex() - 1;
@@ -670,6 +667,12 @@ bool Engine::eventCallback(MidiEvent inEv)
         logEventCount++;
     }
 
+    /* from here on we handle Note Off events as Note On / Vel 0 events */
+    if (inEv.type == EV_NOTEOFF) {
+        inEv.type = EV_NOTEON;
+        inEv.value = 0;
+    }
+
     if (useMidiClock){
         if (inEv.type == EV_START) {
             setStatus(true);
