@@ -4,7 +4,7 @@
  *
  * @section LICENSE
  *
- *      Copyright 2009 - 2013 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -41,10 +41,17 @@
 #include "globstore.h"
 
 /*!
- * @brief Small class implementing a 5ms timer replacing QTimer
+ * @brief 5ms timer calling the updateDisplay() function periodically
  *
- * This class produces MTimer::timeout() signals every 5ms. It consumes
- * about 10 times less CPU than QTimer with the same interval.
+ * This class produces timeout() signals every 5ms. The signal
+ * is connected to the Engine::updateDisplay() method. This mechanism is used
+ * to update many GUI elements as a function of changes happening in the
+ * backend's realtime thread. For example, cursor redrawing cannot be called
+ * directly from the driver. The modules' updateDisplay() functions therefore
+ * only read the position and redraw their screens within this MTimer thread. 
+ * 
+ * MTimer consumes about 10 times less CPU than QTimer with the
+ * same interval.
  *
  */
 class MTimer : public QThread
@@ -62,7 +69,7 @@ protected:
 };
 
 /*!
- * @brief Core Engine Thread. Instantiates SeqDriver and JackDriver.
+ * @brief Core Engine Class. Instantiates SeqDriver and JackDriver.
  *
  * For each module type there is a QList for each of
  * its components (for example MidiArp and ArpWidget). In parallel there is
@@ -70,11 +77,11 @@ protected:
  * Engine also instantiates the MIDI Driver backend and processes MIDI
  * events coming in and going out. It dispatches incoming events to the
  * worker modules and schedules resulting events back to the driver.
- * Controller events are dispatched to the modules as requiered by their
- * MIDI Learn MidiCCList.
+ * Controller events are dispatched to the modules as required by their
+ * MidiControl::ccList.
  *
  */
-class Engine : public QThread  {
+class Engine : public QObject  {
 
   Q_OBJECT
 
@@ -202,9 +209,18 @@ class Engine : public QThread  {
 * with the passed name
 *
 * @param name New name attribute of the DockWidget
-* @param index The widget ID of the DockWidget to rename
+* @param windowID window ID of the DockWidget to rename
+* @param widgetID widgetID of the module to rename
 */
     void renameDock(const QString& name, int windowID, int widgetID);
+/*!
+* @brief  Sets the transport status running or stopped
+*
+* Clears all MidiArp note buffers and calls the appropriate transport
+* start/stop functions in the driver backend.
+* 
+* @param on Run or Stop
+*/
     void setStatus(bool);
 /**
  * @brief Sets the modified flag, which is queried before
@@ -213,9 +229,48 @@ class Engine : public QThread  {
  * @param m Set to True if parameter modifications are present
  */
     void setModified(bool);
+/**
+ * @brief Slot for ArpWidget::presetsChanged() signal
+ * 
+ * Called by an individual ArpWidget when its pattern presets changed. It
+ * causes all other ArpWidget modules to store the modified presets as
+ * well. It saves the preset list to the .qmidiarprc resource file.
+ * 
+ * @param n Name of the modified preset
+ * @param p Pattern string of the modified preset
+ * @param index location within the preset list
+ * 
+ */
     void updatePatternPresets(const QString& n, const QString& p, int index);
+/**
+ * @brief Dispatches a controller MIDI event to all concerned widgets
+ *
+ * Concerned widgets are those containing MIDI-learnable elements. 
+ *
+ * @param ccnumber MIDI Control Event number
+ * @param channel MIDI Control Event channel
+ * @param value MIDI Control Event value
+ */
     void sendController(int ccnumber, int channel, int value);
+/**
+ * @brief Checks all concerned widgets if they requested a MIDI learn
+ *
+ * Causes a module that requested MIDI-learn to learn this controller
+ * event.
+ *
+ * @param ccnumber MIDI Control Event number
+ * @param channel MIDI Control Event channel
+ */
     void learnController(int ccnumber, int channel);
+/**
+ * @brief Engine internal MIDI Controller handler for MIDI learn
+ *
+ * Only the tempo is currently MIDI-learnable and controllable
+ *
+ * @param ccnumber MIDI Control Event number
+ * @param channel MIDI Control Event channel
+ * @param value MIDI Control Event value
+ */
     void handleController(int ccnumber, int channel, int value);
 /**
  * @brief Slot for MidiControl::setMidiLearn(). Sets Engine into MIDI Learn status for
@@ -266,7 +321,7 @@ class Engine : public QThread  {
     void setGrooveLength(int grooveLength);
 /**
  * @brief turns on and off the recording and transfer of received MIDI
- * events to the LogWidget via the Engine::midiEventReceived signal
+ * events to the LogWidget via the midiEventReceived signal
  *
  * This is a slot for LogWidget::enableLogToggle() called when the
  * log window checkbox is clicked.
@@ -292,8 +347,8 @@ class Engine : public QThread  {
  *
  * It queries all module midi workers for direct event eligibility and if
  * not routes it to all module's handleController() methods. If logging
- * is enabled, it stores the event in the Engine::logEventBuffer, which
- * is regularly transferred to the LogWidget by Engine::updateDisplay().
+ * is enabled, it stores the event in the logEventBuffer, which
+ * is regularly transferred to the LogWidget by updateDisplay().
  *
  * @param inEv MidiEvent structure that should be handled
  */
@@ -307,7 +362,7 @@ class Engine : public QThread  {
  * composes and sends the new MIDI events back in the driver's queue along
  * with their tick time at which they should be played out.
  * It also updates the cursors and sets the module and global indicator
- * pacman. It causes parameter Engine::restore() in case global restores
+ * pacman. It causes parameter restore() in case global restores
  * are pending.
  *
 * @param echo_from_trig True if this echo was generated by a trigger through
@@ -315,17 +370,25 @@ class Engine : public QThread  {
  */
     void echoCallback(bool echo_from_trig);
     void resetTicks(int curtick);
+/*!
+* @brief Called by the display MTimer event loop
+
+* Dispatches the periodic call by the MTimer thread to all widgets, which
+* will perform their associated operations. 
+*/
     void updateDisplay();
 /*!
-* @brief causes the module of type Engine::restoreModType at position
-* Engine::restoreModIx in the moduleWidgetList to restore its current
-* parameters from its ParStore::list at index ix. If Engine::restoreModType
-* is set to -1, all modules are called for restore.
+* @brief causes all modules to restore their parameters from its
+* ParStore::list at index ix.
 *
 * @param ix ParStore::list index from which all module parameters are to be restored
 */
     void restore(int ix);
-
+/*!
+* @brief causes Engine to call restore() when the restore conditions are met
+*
+* @param ix ParStore::list index from which all module parameters are to be restored
+*/
     void schedRestore(int ix);
 /*!
 * @brief causes all modules to remove their entries in the ParStore::list
@@ -338,27 +401,23 @@ class Engine : public QThread  {
 * @brief causes all modules to store their current parameters in their
 * ParStore::list at index ix
 *
-* @param moduleID module window list index of the module to store its parameters, -1 for all
 * @param ix ParStore::list index at which all module parameters are to be stored
 */
     void store(int ix);
 /*!
-* @brief causes Engine to call Engine::restore() when the timing and
+* @brief causes Engine to call restore() when the timing and
 * restore type conditions are met
-* @param windowIndex Engine::moduleWindowList index of the module which should
-* restore its parameters. If windowIndex is set to -1, all modules are called
 * @param ix ParStore::list index from which all module parameters are to be restored
-* @param runOnce Set this to true to provoke a return to previous location after one run
 */
     void requestRestore(int ix);
 /*!
-* @brief signal slot for GlobStore::updateGlobRestoreTimeModule signal
+* @brief slot for GlobStore::updateGlobRestoreTimeModule signal
 *
 * Makes the module with index windowIndex trigger global store switches when its cursor
 * reaches the end. It determines the type (Arp, LFO, Seq) and the index of the selected
 * module the module storage lists and stores these in local variables.
 *
-* @param windowIndex Engine::moduleWindowList index of the module to become switch
+* @param windowIndex moduleWindowList index of the module to become switch
 * trigger when its cursor reaches the end of the pattern
 */
     void updateGlobRestoreTimeModule(int windowIndex);
