@@ -4,7 +4,7 @@
  *
  * @section LICENSE
  *
- *      Copyright 2009 - 2013 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -160,7 +160,7 @@ void GlobStore::addLocation()
     QToolButton *storeButton = new QToolButton(this);
     storeButton->setDefaultAction(storeAction);
     storeButton->setFixedSize(15, 25);
-    storeAction->setIcon(QIcon(filesave_xpm));
+    storeAction->setIcon(QPixmap(filesave_xpm));
     connect(storeAction, SIGNAL(triggered()), storeSignalMapper, SLOT(map()));
     storeSignalMapper->setMapping(storeAction, widgetList.count());
 
