@@ -4,7 +4,7 @@
  *
  * @section LICENSE
  *
- *      Copyright 2009 - 2013 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -56,7 +56,7 @@
 
 static const char ABOUTMSG[] =
             "<html> <p><b><big>" APP_NAME " " PACKAGE_VERSION "</big></b></p>"
-            "<p>(C) 2009-2013 Frank Kober<br/>"
+            "<p>(C) 2009-2014 Frank Kober<br/>"
             "(C) 2011 Nedko Arnaudov<br/>"
             "(C) 2009 Guido Scholz<br/>"
             "(C) 2002-2003 Matthias Nagorni (SuSE AG Nuremberg)<br/></p>"
@@ -115,10 +115,8 @@ class MainWindow : public QMainWindow
 #endif
     void skipXmlElement(QXmlStreamReader& xml);
 /*!
-* @brief  opens a file dialog and calls either
-* MainWindow::openTextFile or
-* MainWindow::openFile depending on the selected file extension.
-* It is called by MainWindow::fileOpen.
+* @brief  opens a file dialog and calls MainWindow::openFile().
+* It is called by MainWindow::fileOpen().
 */
     void chooseFile();
 /*! @brief  checks whether parameter modifications
@@ -156,47 +154,54 @@ class MainWindow : public QMainWindow
 *
 * It also creates and adds the associated ArpWidget
 * and DockWidget to the corresponding lists in Engine. It sets
-* the ArpWidget::name and ArpWidget::ID as the current count of the
-* Engine::MidiArpList.
+* the ManageBox::name and ManageBox::ID as the current count of the
+* Engine::midiArpList.
 *
 * @param name Name attribute of the created arpeggiator module
 * @param fromfile Set to True if module is added by a file read
+* @param inOutVisible Set to True if In-Out panel should be shown
 */
-    void addArp(const QString&, bool fromfile = false, bool inOutVisible = true);
+    void addArp(const QString& name, bool fromfile = false,
+                bool inOutVisible = true);
 /*!
 * @brief  creates and adds a new MidiLfo to Engine.
 *
 * It also creates and adds the associated LfoWidget
 * and DockWidget to the corresponding lists in Engine. It sets
-* the LfoWidget::name and SeqWidget::ID as the current count of the
-* Engine::MidiLfoList.
+* the ManageBox::name and ManageBox::ID as the current count of the
+* Engine::midiLfoList.
 *
 * @param name Name attribute of this LFO module
 * @param fromfile Set to True if module is added by a file read
 * @param clonefrom Set to the ID to clone this module from,
 * -1 for a new module (default)
+* @param inOutVisible Set to True if In-Out panel should be shown
 */
-    void addLfo(const QString&, bool fromfile = false, int clonefrom = -1, bool inOutVisible = true);
+    void addLfo(const QString& name, bool fromfile = false,
+                int clonefrom = -1, bool inOutVisible = true);
 /*!
 * @brief  creates and adds a new MidiSeq to Engine.
 *
 * It also creates and adds the associated SeqWidget
 * and DockWidget to the corresponding lists in Engine. It sets
-* the SeqWidget::name and SeqWidget::ID as the current count of the
-* Engine::MidiSeqList.
+* the ManageBox::name and ManageBox::ID as the current count of the
+* Engine::midiSeqList.
 *
-* @param name Name attribute of this arpeggiator module
+* @param name Name attribute of this module
 * @param fromfile Set to True if module is added by a file read
 * @param clonefrom Set to the ID to clone this module from,
 * -1 for a new module (default)
+* @param inOutVisible Set to True if In-Out panel should be shown
 */
-    void addSeq(const QString&, bool fromfile = false, int clonefrom = -1, bool inOutVisible = true);
+    void addSeq(const QString& name, bool fromfile = false,
+                int clonefrom = -1, bool inOutVisible = true);
 /*!
 * @brief  wraps the given widget in a QDockWidget and adds
 * it to the list in Engine.
 *
 * @param *moduleWidget The QWidget to be embedded
-*
+* @param name Name attribute of this module
+* @param count DockWidget list location at which the window is insertet
 */
     void appendDock(QWidget *moduleWidget, const QString& name, int count);
 /*!
@@ -341,6 +346,8 @@ class MainWindow : public QMainWindow
   public:
 /*!
 * @param p_portCount Number of registered MIDI output ports
+* @param p_alsamidi Start as ALSA MIDI client
+* @param *execName Name of the application's executable
 */
     MainWindow(int p_portCount, bool p_alsamidi, char *execName);
     ~MainWindow();
@@ -444,7 +451,7 @@ class MainWindow : public QMainWindow
 * It removes all components MidiSeq, SeqWidget and
 * DockWidget from the corresponding lists in Engine.
 *
-* @param index The Engine::MidiSeqList index of the sequencer to remove
+* @param index The Engine::midiSeqList index of the sequencer to remove
 */
     void removeSeq(int index);
 /*!
@@ -463,7 +470,7 @@ class MainWindow : public QMainWindow
     void helpAbout();
     void helpAboutQt();
 /*! @brief Slot for tempo spinBox changes.
-* This function forwards a new tempo value to SeqDriver.
+* This function forwards a new tempo value to the driver.
 * @param tempo The new tempo to be set
 *
 */
@@ -471,7 +478,7 @@ class MainWindow : public QMainWindow
 /*! @brief Slot for Engine::tempoUpdated() signal.
 *
 * This function displays a new tempo value in the tempo spin box.
-* @param tempo The new tempo to be displayed
+* @param p_tempo The new tempo to be displayed
 *
 */
     void displayTempo(double p_tempo);
@@ -491,7 +498,7 @@ class MainWindow : public QMainWindow
 */
     void midiClockToggle(bool on);
 /*! @brief Slot for jackSync ToolButton.
-* This function toggles SeqDriver between Jack Transport and internal
+* This function toggles the driver between Jack Transport and internal
 * clock operation.
 * @param on True sets driver to JACK Transport operation, false
 * returns to internal clock.
