@@ -4,7 +4,7 @@
  *
  * @section LICENSE
  *
- *      Copyright 2009 - 2013 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -103,6 +103,12 @@ MidiArp::MidiArp()
     minStepWidth = 1.0;
     maxOctave = 0;
     minOctave = 0;
+    
+    octMode = 0;
+    octRange = 1;
+    octOfs = 0;
+    octIncr = 0;
+
     nSteps = 1.0;
     nPoints = 1;
     len = 0.5;       // note length
@@ -112,8 +118,6 @@ MidiArp::MidiArp()
     grooveIndex = 0;
     patternLen = 0;
     semitone = 0;
-    newCurrent = false;
-    newNext = false;
     currentNoteTick = 0;
     nextTick = 0;
     patternMaxIndex = 0;
@@ -128,6 +132,7 @@ MidiArp::MidiArp()
     randomLengthAmp = 0;
     grooveTick = 0;
     newGrooveTick = 0;
+    hasNewNotes = false;
     grooveVelocity = 0;
     grooveLength = 0;
     repeatPatternThroughChord = 1;
@@ -144,7 +149,7 @@ MidiArp::MidiArp()
     latchBuffer.resize(64);
     latchBufferCount = 0;
     lastLatchTick = 0;
-    trigDelayTicks = 2;
+    trigDelayTicks = 4;
 
     returnNote.resize(128);
     returnVelocity.resize(128);
@@ -180,23 +185,25 @@ bool MidiArp::handleEvent(MidiEvent inEv, int tick, int keep_rel)
         || ((inEv.value < rangeIn[0]) || (inEv.value > rangeIn[1]))) {
         return(true);
     }
+    
+    // modify buffer that is not accessed by arpeggio output
+    bufPtr = (noteBufPtr) ? 0 : 1;
 
     if (inEv.value) {
         // This is a NOTE ON event
+
         if (!getPressedNoteCount() || trigLegato) {
             purgeLatchBuffer();
             if (restartByKbd) restartFlag = true;
             // if we have been triggered, remove pending release notes
             if (trigByKbd && release_time > 0) {
                 for (int l1 = 0; l1 < noteCount; l1++) {
-                    if (notes[noteBufPtr][3][l1])
-                        removeNote(&notes[noteBufPtr][0][l1], -1, 0);
+                    if (notes[bufPtr][3][l1])
+                        removeNote(&notes[bufPtr][0][l1], -1, 0);
                         releaseNoteCount--;
                 }
             }
         }
-        // modify buffer that is not accessed by arpeggio output
-        bufPtr = (noteBufPtr) ? 0 : 1;
 
         if (!noteCount || (inEv.data > notes[bufPtr][0][noteCount - 1]))
             index = noteCount;
@@ -217,15 +224,17 @@ bool MidiArp::handleEvent(MidiEvent inEv, int tick, int keep_rel)
         noteCount++;
 
         if (repeatPatternThroughChord == 2) noteOfs = noteCount - 1;
-        if ((trigByKbd && (getPressedNoteCount() == 1)) || trigLegato) {
+
+        if ((trigByKbd
+                && ((noteCount - latchBufferCount - releaseNoteCount) == 1))
+                    || trigLegato) {
             initArpTick(tick + trigDelayTicks);
             gotKbdTrig = true;
         }
     }
     else {
         // This is a NOTE OFF event
-        // modify buffer that is not accessed by arpeggio output
-        bufPtr = (noteBufPtr) ? 0 : 1;
+
         if (!noteCount) {
             return(false);
         }
@@ -347,7 +356,9 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
 {
     QChar c;
     int l1, tmpIndex[MAXCHORD], chordIndex, grooveTmp;
-    bool gotCC, outOfRange, pause;
+    int current_octave = 0;
+    int outOfRange = 0;
+    bool gotCC, pause;
     double attackfn, releasefn;
 
 
@@ -429,13 +440,16 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
                 chordSemitone[chordIndex] = semitone;
             }
         }
+        current_octave = octOfs;
     } while (advancePatternIndex(false) && (gotCC || chordMode));
 
     l1 = 0;
     if (noteCount) do {
         noteIndex[l1] = (noteCount) ? tmpIndex[l1] % noteCount : 0;
-        note[l1] = clip(notes[noteBufPtr][0][noteIndex[l1]]
+        note[l1] = clip(notes[noteBufPtr][0][noteIndex[l1]] + current_octave * 12
                 + chordSemitone[l1], 0, 127, &outOfRange);
+        if (outOfRange != 0) checkOctaveAtEdge(false);
+
         grooveTmp = (grooveIndex % 2) ? -grooveVelocity : grooveVelocity;
 
         if ((release_time > 0) && (notes[noteBufPtr][3][noteIndex[l1]])) {
@@ -471,8 +485,8 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
         else {
             l1++;
         }
-    } while (  (tmpIndex[l1] >= 0)
-            && (l1 < MAXCHORD - 1)
+    } while (  (l1 < MAXCHORD - 1)
+            && (tmpIndex[l1] >= 0)
             && ((l1 < noteCount) || (tmpIndex[l1] == 0))
             && (noteCount));
 
@@ -506,6 +520,35 @@ void MidiArp::getNote(int *tick, int note[], int velocity[], int *length)
     grooveIndex++;
 }
 
+void MidiArp::checkOctaveAtEdge(bool reset)
+{
+    if (!octMode) return;
+    
+    if (reset) {
+        octOfs = 0;
+        if (octMode == 2) octIncr = -1; else octIncr = 1;
+        return;
+    }
+    if (octOfs > octRange) {
+        if (octMode == 3){
+            octIncr = - octIncr;
+            octOfs--;
+        }
+        else {
+            octOfs = -octRange;
+        }
+    }
+    if (octOfs < -octRange) {
+        if (octMode == 3) {
+            octIncr = - octIncr;
+            octOfs++;
+        }
+        else {
+            octOfs = octRange;
+        }
+    }
+}
+
 bool MidiArp::advancePatternIndex(bool reset)
 {
     if (patternLen) {
@@ -522,6 +565,8 @@ bool MidiArp::advancePatternIndex(bool reset)
                 noteOfs++;
                 if ((noteCount - 1 < patternMaxIndex + noteOfs) || reset) {
                     noteOfs = 0;
+                    octOfs+=octIncr;
+                    checkOctaveAtEdge(reset);
                 }
                 break;
             case 2:
@@ -529,6 +574,8 @@ bool MidiArp::advancePatternIndex(bool reset)
                 if ((noteCount -1 < patternMaxIndex) ||
                     (noteOfs < patternMaxIndex) || reset) {
                     noteOfs = noteCount - 1;
+                    octOfs+=octIncr;
+                    checkOctaveAtEdge(reset);
                 }
                 break;
             case 3:
@@ -554,39 +601,25 @@ void MidiArp::initLoop()
 void MidiArp::prepareCurrentNote(int askedTick)
 {
     gotKbdTrig = false;
-    currentTick = askedTick;
-    int l1 = 0;
-    updateNotes();
-    returnTick = currentNoteTick;
-    while ((currentNote[l1] >= 0) && (l1 < MAXCHORD - 1)) {
-        returnNote.replace(l1, currentNote[l1]);
-        returnVelocity.replace(l1, currentVelocity[l1]);
-        l1++;
-    }
-    returnNote.replace(l1, -1); // mark end of chord
-    returnLength = currentLength;
-    returnIsNew = newCurrent;
-    newCurrent = false;
-}
 
-void MidiArp::updateNotes()
-{
     int l1 = 0;
-
     //allow 8 ticks of tolerance for echo tick for external sync
-    if ((currentTick + 8) >= currentNoteTick) {
+    if ((askedTick + 8) >= currentNoteTick) {
         currentNoteTick = nextTick;
         getNote(&nextTick, nextNote, nextVelocity, &nextLength);
-        while ((nextNote[l1] >= 0) && (l1 < MAXCHORD - 1)) {
-            currentNote[l1] = nextNote[l1];
-            currentVelocity[l1] = nextVelocity[l1];
+        while ((l1 < MAXCHORD - 1) && (nextNote[l1] >= 0)) {
+            returnNote.replace(l1, nextNote[l1]);
+            returnVelocity.replace(l1, nextVelocity[l1]);
             l1++;
         }
-        currentNote[l1] = -1; // mark end of chord
-        currentLength = nextLength;
-        newCurrent = true;
-        newNext = true;
+        returnLength = nextLength;
+        hasNewNotes = true;
     }
+    else hasNewNotes = false;
+    
+    returnNote.replace(l1, -1); // mark end of chord
+
+    returnTick = currentNoteTick;
 }
 
 void MidiArp::foldReleaseTicks(int tick)
@@ -605,7 +638,7 @@ void MidiArp::foldReleaseTicks(int tick)
 void MidiArp::initArpTick(int tick)
 {
     arpTick = tick;
-    currentVelocity[0] = 0;
+    returnVelocity.first() = 0;
     currentNoteTick = tick;
     nextTick  = tick;
     nextVelocity[0] = 0;
@@ -729,17 +762,17 @@ void MidiArp::updatePattern(const QString& p_pattern)
     nPoints = npoints;
 }
 
-int MidiArp::clip(int value, int min, int max, bool *outOfRange)
+int MidiArp::clip(int value, int min, int max, int *outOfRange)
 {
     int tmp = value;
 
     *outOfRange = false;
     if (tmp > max) {
         tmp = max;
-        *outOfRange = true;
+        *outOfRange = 1;
     } else if (tmp < min) {
         tmp = min;
-        *outOfRange = true;
+        *outOfRange = -1;
     }
     return(tmp);
 }
@@ -759,6 +792,30 @@ void MidiArp::updateRandomTickAmp(int val)
     randomTickAmp = val;
 }
 
+void MidiArp::updateOctaveMode(int val)
+{
+    octMode = val;
+    octOfs = 0;
+    
+    switch (val) {
+        case 0: 
+            octIncr = 0;
+        break;
+
+        case 1:
+            octIncr = 1;
+        break;
+
+        case 2:
+            octIncr = -1;
+        break;
+
+        case 3:
+            octIncr = 1;
+        break;
+    }
+}
+
 void MidiArp::updateRandomVelocityAmp(int val)
 {
     randomVelocityAmp = val;
