@@ -4,7 +4,7 @@
  *
  * @section LICENSE
  *
- *      Copyright 2009 - 2013 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -33,26 +33,21 @@
 
  /*!
  * @brief MIDI worker class for the Arpeggiator Module. Implements the
- * functions providing note arpeggiation as a QWidget.
+ * functions providing note arpeggiation.
  *
  * The parameters of MidiArp are controlled by the ArpWidget class.
- * A pointer to MidiArp is passed to the Engine, which calls
- * the MidiArp::prepareCurrentNote member as a function of the position of
- * the Driver queue. MidiArp will then call its
- * internal MidiArp::getNote function which produces an array of notes
+ * The backend driver thread calls the Engine::echoCallback(), which will
+ * query each module, in this case via
+ * the MidiArp::prepareCurrentNote() method. MidiArp will then call its
+ * internal MidiArp::getNote() function which produces an array of notes
  * stored in its internal output buffer. The notes in the array depend
  * on the active MidiArp::pattern, envelope, random and groove settings.
  * The note events consist of timing information
- * (tick and length), note values and velocity values. MidiArp::getNote
- * also advances the pattern index and emits the MidiArp::nextStep signal
- * to update the cursor position in the graphical ArpScreen display part
- * of ArpWidget. Engine then
- * accesses this output buffer and sends it to the Driver queue. Engine
- * also calls MidiArp::handleNoteOn and MidiArp::handleNoteOff. These members
- * manage the arpeggiator input note buffer
- * also part of this class. Notes received on the MIDI input port will
- * therefore be added or removed from the buffer as Engine transfers
- * them to this class.
+ * (tick and length), note values and velocity values. MidiArp::getNote()
+ * also advances the pattern index. Engine::tickCallback() then
+ * accesses this output buffer and sends it to the backend driver. Engine
+ * also calls MidiArp::handleEvent() in particular to store incoming notes
+ * in its note buffer. 
  */
 class MidiArp : public QObject  {
 
@@ -63,10 +58,9 @@ class MidiArp : public QObject  {
                                 @see MidiArp::updateNotes */
     int nextVelocity[MAXCHORD]; /*!< Holds the associated velocities to be output next
                                     @see MidiArp::updateNotes, MidiArp::nextNote */
-    int currentNoteTick, currentTick, arpTick;
-    int currentNote[MAXCHORD], currentVelocity[MAXCHORD];
-    int currentLength, nextLength;
-    bool newCurrent, newNext, chordMode;
+    int currentNoteTick, arpTick;
+    int nextLength;
+    bool chordMode;
     bool restartFlag; /*!< Signals frameptr reset on next getNextFrame() call */
     int patternIndex; /*!< Holds the current position within the pattern text*/
     int grooveIndex; /*!< Holds the current position within the sequence*/
@@ -109,10 +103,12 @@ class MidiArp : public QObject  {
     int noteCount;      /*!< The number of notes in the MidiArp::notes buffer */
     int patternLen;     /*!< Length of the arp text pattern */
     int noteOfs;        /*!< The current index in a chord. @see repeatPatternThroughChord */
+    int octOfs;        /*!< The currently active octave shift. @see repeatPatternThroughChord */
+    int octIncr;        /*!< The octave increment at repeat end. @see repeatPatternThroughChord */
     int releaseNoteCount; /*!< The number of notes currently in release stage */
 
 /**
- * @brief This function resets all attributes the pattern
+ * @brief  resets all attributes the pattern
  * accumulates during run.
  *
  * It is called when the currentIndex revolves to restart the loop with
@@ -120,43 +116,34 @@ class MidiArp : public QObject  {
 */
     void initLoop();
 /**
- * @brief This function allows forcing an integer value within the
+ * @brief  allows forcing an integer value within the
  * specified range (clip).
  *
  * @param value The value to be checked
  * @param min The minimum allowed return value
  * @param max The maximum allowed return value
- * @param outOfRange Is set to True if value was outside min|max range
+ * @param outOfRange Is set to -1|1 if value was outside min|max range
  * @return The value clipped within the range
  */
-    int clip(int value, int min, int max, bool *outOfRange);
-/**
- * @brief This function updates the current note arrays with new values
- * obtained from MidiArp::getNote
- *
- * It is called by Engine::echoCallback() and calls MidiArp::getNote if the given
- * timing is ahead of the last timing information. It then transfers the
- * MidiArp::nextNote and MidiArp::nextVelocity arrays into
- * MidiArp::currentNote and MidiArp::currentVelocity.
- *
- */
-    void updateNotes();
+    int clip(int value, int min, int max, int *outOfRange);
 /**
  * @brief This is MidiArp's main note processor producing output notes
  * from input notes.
  *
  * It analyzes the MidiArp::pattern text and MidiArp::notes input buffer
- * to yield arrays of notes that have to be output at the given timing.
+ * to yield arrays of notes that have to be sent at the given timing.
+ * The calculated note data is stored in arrays, copied again by
+ * prepareCurrentNote() and the copy is accessed by Engine::echoCallback().
  * Only in case of an arpeggio step involving chords, these arrays have
  * sizes > 1.
- * @param tick The timing of the requested arpeggio step
+ * @param tick The timing of the notes to be scheduled
  * @param note The array of notes to be filled
  * @param velocity The associated array of velocites to be filled
  * @param length The note length for this arpeggio step
  */
     void getNote(int *tick, int note[], int velocity[], int *length);
 /**
- * @brief This function returns the number of notes present at the MIDI
+ * @brief  returns the number of notes present at the MIDI
  * input port.
  *
  * This is the number of notes currently pressed on the keyboard. Note
@@ -168,7 +155,7 @@ class MidiArp : public QObject  {
  */
     int getPressedNoteCount();
 /**
- * @brief This function returns the number of notes present at the MIDI
+ * @brief  returns the number of notes present at the MIDI
  * input port.
  *
  * This is the number of notes currently pressed on the keyboard. Note
@@ -180,7 +167,7 @@ class MidiArp : public QObject  {
  */
     void removeNote(int *noteptr, int tick, int keep_rel);
 /**
- * @brief This function removes a note inside the MidiArp::notes input
+ * @brief  removes a note inside the MidiArp::notes input
  * note buffer.
  *
  * The note  at the given index is deleted from the buffer with the
@@ -191,7 +178,7 @@ class MidiArp : public QObject  {
  */
     void deleteNoteAt(int index, int bufPtr);
 /**
- * @brief This function sets the released flag (value 1) for the note
+ * @brief  sets the released flag (value 1) for the note
  * at the given index
  *
  * This operation is done for the buffer with given bufPtr index (0 or 1).
@@ -205,10 +192,16 @@ class MidiArp : public QObject  {
  */
     void tagAsReleased(int note, int tick, int bufPtr);
 /**
- * @brief This function performs a copy within MidiArp::notes from the
+ * @brief  performs a copy within MidiArp::notes from the
  * currently active index to the inactive index
  */
     void copyNoteBuffer();
+/**
+ * @brief Advances octOfs according to the settings. Called when the octave
+ * reaches an edge condition (at octave range or outside permitted range)
+ * @param reset Set to True in order to set the octave shift to zero
+ */
+    void checkOctaveAtEdge(bool reset);
 
   public:
     int chIn;       /*!< Input channel state set by ArpWidget */
@@ -225,6 +218,7 @@ class MidiArp : public QObject  {
     bool trigByKbd; /*!< If True, trigger current note tick by tick of received note, set by ArpWidget */
     bool trigLegato; /*!< If True, trigger and restart upon legato input notes as well */
     bool gotKbdTrig; /*!< Is set when a keyboard trigger is activated by a note */
+    bool hasNewNotes; /*!< True when prepareCurrentNote() was called with a tick causing new note calculation */
     int repeatPatternThroughChord; /*!< Repeat mode "Static", "Up", "Down", set by ArpWidget */
     double attack_time;/*!< Attack time in seconds, set by ArpWidget */
     double release_time;/*!< Release time in seconds, set by ArpWidget */
@@ -240,12 +234,13 @@ class MidiArp : public QObject  {
     double nSteps;      /*!< Musical length of the pattern in beats */
     int nPoints;        /*!< Number of steps to be played out */
     int patternMaxIndex;/*!< Maximum number of stacked notes in the pattern */
+    int octMode;        /*!< The octave Mode 0=up, 1=down, 2=pingpong. @see repeatPatternThroughChord */
+    int octRange;        /*!< The maximum range of octaves. @see repeatPatternThroughChord */
 
     QVector<int> returnNote; /*!< Holds the notes of the currently active arpeggio step */
     QVector<int> returnVelocity; /*!< Holds the velocities of the currently active arpeggio step */
     int returnTick; /*!< Holds the time in internal ticks of the currently active arpeggio step */
     int returnLength; /*!< Holds the note length of the currently active arpeggio step */
-    int returnIsNew;
     int nextTick; /*!< Holds the next tick at which note events will be played out */
 
     bool needsGUIUpdate;
@@ -261,20 +256,20 @@ class MidiArp : public QObject  {
     void updateRandomLengthAmp(int);
     void updateAttackTime(int);
     void updateReleaseTime(int);
-/*! @brief This function sets MidiArp::isMuted, which is checked by
+/*! @brief  sets MidiArp::isMuted, which is checked by
  * Engine and which suppresses data output globally if set to True.
  *
  * @param on Set to True to suppress data output to the Driver
  */
     void setMuted(bool);
-/*! @brief This function sets MidiArp::deferChanges, which will cause a
+/*! @brief  sets MidiArp::deferChanges, which will cause a
  * parameter changes only at pattern end.
  *
  * @param on Set to True to defer changes to pattern end
  */
     void updateDeferChanges(bool on) { deferChanges = on; }
 /**
- * @brief This function calculates the index of the next arpeggio
+ * @brief  calculates the index of the next arpeggio
  * step and revolves it if necessary.
  *
  * The next step depends on the MidiArp::repeatPatternThrough chord mode.
@@ -285,45 +280,44 @@ class MidiArp : public QObject  {
  */
     bool advancePatternIndex(bool reset);
 /**
- * @brief This function does the actions related to a newly received event.
+ * @brief  does the actions related to a newly received event.
  *
  * It is called by Engine when a new event is received on the MIDI input port.
 
  * @param inEv MidiEvent to check and process or not
  * @param tick The time the event was received in internal ticks
+ * @param keep_rel If set to True, a NOTE_OFF event should cause the note to
+ * remain in the release buffer. It will definitely be removed if keep_rel is false
  * @return True if inEv is in not the input range of the module (event is unmatched)
  */
     bool handleEvent(MidiEvent inEv, int tick, int keep_rel = 0);
 /**
- * @brief This function represents the external interface to the
- * core of the arpeggiator engine.
+ * @brief Causes calculation of a new note set at a step and copies it
+ * to arrays accessed by Engine.
  *
- * It is called by Engine when a previously scheduled echo
- * event is received from the driver.
- * It starts the MidiArp::run thread. In the thread, MidiArp::getNote
- * is called, which does the note processing depending on the
- * MidiArp::pattern and
- * leading to new data in MidiArp::returnNote, MidiArp::returnVelocity,
- * MidiArp::returnLength. Engine then accesses this data directly
- * and outputs it to the Driver's queue.
+ * It is called by Engine::echoCallback() when a previously scheduled echo
+ * event is received from the driver. It calls MidiArp::getNote().
+ * It copies the new data to MidiArp::returnNote, MidiArp::returnVelocity,
+ * MidiArp::returnLength. Engine::echoCallback() then accesses this
+ * data directly and transfers it to the driver.
  *
- * @param askedTick the timing of the note(s) to be output
+ * @param askedTick the current transport position in ticks.
  *
  */
     void prepareCurrentNote(int askedTick);
 /**
- * @brief This function resets the pattern index and sets the current
+ * @brief  resets the pattern index and sets the current
  * timing of the arpeggio to currentTick.
  *
  * It is called by Engine when the transport is started, or when
  * a stakato note is received while MidiArp::restartByKbd is set.
  *
- * @param currentTick The timing in internal ticks, relative to which
+ * @param tick The timing in internal ticks, relative to which
  * the following arpeggio notes are calculated.
  */
     void initArpTick(int tick);
 /**
- * @brief This function ensures continuity of the release function
+ * @brief  ensures continuity of the release function
  * when the currentTick position jumps into
  * the past.
  *
@@ -334,10 +328,10 @@ class MidiArp : public QObject  {
  */
     void foldReleaseTicks(int tick);
 /**
- * @brief This function seeds new random values for the three parameters
+ * @brief  seeds new random values for the three parameters
  * concerned, timing (tick), velocity and length.
  *
- * This function is
+ * It is
  * called by MidiArp::getNote at every new note. It uses the
  * MidiArp::randomTickAmp, MidiArp::randomVelocityAmp and
  * MidiArp::randomLengthAmp settings coming from ArpWidget.
@@ -345,7 +339,7 @@ class MidiArp : public QObject  {
  */
     void newRandomValues();
 /**
- * @brief This function copies the new values transferred from the
+ * @brief  copies the new values transferred from the
  * GrooveWidget into variables used by MidiArp::getNote.
  *
  * @param p_grooveTick Groove amount for timing displacements
@@ -364,13 +358,13 @@ class MidiArp : public QObject  {
  /*! @brief Will cause notes remaining in MidiArp::latchBuffer until new
   * stakato note received
   *
-  * This function is called by ArpWidget::setLatchMode
+  *  It is called by ArpWidget::setLatchMode
   */
     void setLatchMode(bool);
  /*! @brief Calls MidiArp::removeNote for all notes in MidiArp::sustainBuffer
   * and then clears sustainBuffer.
   *
-  * This function is called by MidiArp::setSustain
+  *  It is called by MidiArp::setSustain
   * @param sustick Time in internal ticks at which the controller was received */
     void purgeSustainBuffer(int sustick);
  /*! @brief sets MidiArp::noteCount to zero and clears MidiArp::latchBuffer. */
@@ -380,6 +374,11 @@ class MidiArp : public QObject  {
  */
     void applyPendingParChanges();
 
+/*! @brief Sets octave mode and octave increment accordingly, resets the
+ * current octave shift
+ */
+    void updateOctaveMode(int val);
+
   public slots:
  /*! @brief Slot for MidiArp::latchTimer. Calls MidiArp::removeNote for
   * all notes in MidiArp::latchBuffer and then clears latchBuffer.
