@@ -4,7 +4,7 @@
  *
  * @section LICENSE
  *
- *      Copyright 2009 - 2013 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -49,8 +49,8 @@ MidiSeqLV2::MidiSeqLV2 (
     transportFramesDelta = 0;
     curTick = 0;
     tempoChangeTick = 0;
-    transportMode = false;
-    transportSpeed = 1;
+    hostTransport = true;
+    transportSpeed = 0;
     transportAtomReceived = false;
 
     transpFromGui = 0;
@@ -110,7 +110,7 @@ void MidiSeqLV2::connect_port ( uint32_t port, void *seqdata )
 
 void MidiSeqLV2::updatePosAtom(const LV2_Atom_Object* obj)
 {
-    if (!transportMode) return;
+    if (!hostTransport) return;
 
     QMidiArpURIs* const uris = &m_uris;
 
@@ -139,13 +139,13 @@ void MidiSeqLV2::updatePosAtom(const LV2_Atom_Object* obj)
 void MidiSeqLV2::updatePos(uint64_t pos, float bpm, int speed, bool ignore_pos)
 {
     if (transportBpm != bpm) {
-        qWarning("tempo changed");
         /* Tempo changed */
         transportBpm = bpm;
         tempo = transportBpm;
+        transportSpeed = 0;
     }
 
-    if (!ignore_pos) {
+    if (!ignore_pos && (transportBpm > 0)) {
         const float frames_per_beat = 60.0f / transportBpm * sampleRate;
         transportFramesDelta = pos;
         tempoChangeTick = pos * TPQN / frames_per_beat;
@@ -156,10 +156,9 @@ void MidiSeqLV2::updatePos(uint64_t pos, float bpm, int speed, bool ignore_pos)
         curFrame = transportFramesDelta;
         if (transportSpeed) {
             setNextTick(tempoChangeTick);
-            Sample sample;
-            getNextNote(&sample, nextTick);
         }
     }
+    //qWarning("transportBpm %f, transportFramesDelta %d", transportBpm, transportFramesDelta);
 }
 
 void MidiSeqLV2::run (uint32_t nframes )
@@ -176,11 +175,12 @@ void MidiSeqLV2::run (uint32_t nframes )
     if (inEventBuffer) {
         LV2_ATOM_SEQUENCE_FOREACH(inEventBuffer, event) {
             // Control Atom Input
-            if (event && event->body.type == uris->atom_Blank) {
+            if (event && (event->body.type == uris->atom_Object
+                        || event->body.type == uris->atom_Blank)) {
                 const LV2_Atom_Object* obj = (LV2_Atom_Object*)&event->body;
                 if (obj->body.otype == uris->time_Position) {
                     /* Received position information, update */
-                    if (transportMode) updatePosAtom(obj);
+                    if (hostTransport) updatePosAtom(obj);
                 }
                 else if (obj->body.otype == uris->ui_up) {
                     /* UI was activated */
@@ -252,7 +252,8 @@ void MidiSeqLV2::run (uint32_t nframes )
                 noteofftick = tmptick;
             }
         }
-        if ((bufPtr) && (curTick >= noteofftick)) {
+        if ( (bufPtr) && ((curTick >= noteofftick)
+                || (hostTransport && !transportSpeed)) ) {
             int outval = evQueue.at(idx);
             for (int l4 = idx ; l4 < (bufPtr - 1);l4++) {
                 evQueue.replace(l4, evQueue.at(l4 + 1));
@@ -261,9 +262,9 @@ void MidiSeqLV2::run (uint32_t nframes )
             bufPtr--;
 
             unsigned char d[3];
-            d[0] = 0x90 + channelOut;
+            d[0] = 0x80 + channelOut;
             d[1] = outval;
-            d[2] = 0;
+            d[2] = 127;
             forgeMidiEvent(f, d, 3);
         }
         curFrame++;
@@ -308,8 +309,6 @@ void MidiSeqLV2::updateParams()
         mouseEvCur = *val[MOUSEPRESSED];
 
         if (mouseEvCur == 2) return; // mouse was released
-        //qWarning("mouse event X: %f - Y: %f - Type: %d - Button %d",
-        //    mouseXCur, mouseYCur, (int)*val[MOUSEBUTTON], mouseEvCur);
         ix = mouseEvent(mouseXCur, mouseYCur, *val[MOUSEBUTTON], evtype);
         if (evtype == 1) lastMouseIndex = ix; // if we have a new press event set last point index here
     }
@@ -364,31 +363,15 @@ void MidiSeqLV2::updateParams()
 
     if (internalTempo != *val[TEMPO]) {
         internalTempo = *val[TEMPO];
-        if (!transportMode) {
-            transportFramesDelta = curFrame;
-            tempoChangeTick = curTick;
-            transportBpm = internalTempo;
-            tempo = internalTempo;
-            setNextTick(tempoChangeTick);
-            getNextNote(&currentSample, nextTick);
-        }
+        initTransport();
     }
 
-    if (transportMode != (bool)(*val[TRANSPORT_MODE])) {
-        transportMode = (bool)(*val[TRANSPORT_MODE]);
-        transportSpeed = 0;
-        if (!transportMode) {
-            transportFramesDelta = curFrame;
-            tempoChangeTick = curTick;
-            transportBpm = internalTempo;
-            tempo = internalTempo;
-            setNextTick(tempoChangeTick);
-            getNextNote(&currentSample, nextTick);
-            transportSpeed = 1;
-        }
+    if (hostTransport != (bool)(*val[TRANSPORT_MODE])) {
+        hostTransport = (bool)(*val[TRANSPORT_MODE]);
+        initTransport();
     }
 
-    if (transportMode && !transportAtomReceived) {
+    if (hostTransport && !transportAtomReceived) {
         updatePos(  (uint64_t)*val[HOST_POSITION],
                     (float)*val[HOST_TEMPO],
                     (int)*val[HOST_SPEED],
@@ -401,6 +384,20 @@ void MidiSeqLV2::updateParams()
     }
 }
 
+void MidiSeqLV2::initTransport()
+{
+    if (!hostTransport) {
+        transportFramesDelta = curFrame;
+        if (curTick > 0) tempoChangeTick = curTick;
+        transportBpm = internalTempo;
+        tempo = internalTempo;
+        transportSpeed = 1;
+    }
+    else transportSpeed = 0;
+
+    setNextTick(tempoChangeTick);
+}
+
 void MidiSeqLV2::sendWave()
 {
     if (!(dataChanged && ui_up)) return;
@@ -516,6 +513,8 @@ static LV2_State_Status MidiSeqLV2_state_save ( LV2_Handle instance,
     uint32_t key = uris->hex_customwave;
     if (!key) return LV2_STATE_ERR_NO_PROPERTY;
 
+    flags |= (LV2_STATE_IS_POD | LV2_STATE_IS_PORTABLE);
+
     store(handle, key, value, size, type, flags);
 
     tempArray.clear();
@@ -544,10 +543,12 @@ static const LV2_State_Interface MidiSeqLV2_state_interface =
 
 void MidiSeqLV2::activate (void)
 {
+    initTransport();
 }
 
 void MidiSeqLV2::deactivate (void)
 {
+    transportSpeed = 0;
 }
 
 static LV2_Handle MidiSeqLV2_instantiate (
