@@ -4,7 +4,7 @@
  *
  * @section LICENSE
  *
- *      Copyright 2009 - 2013 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -130,7 +130,7 @@ ParStore::ParStore(GlobStore *p_globStore, const QString &name,
 
     QAction *storeHereAction = new QAction(tr("&Store here"), this);
     storeHereAction->setProperty("index", list.count());
-    storeHereAction->setIcon(QIcon(filesave_xpm));
+    storeHereAction->setIcon(QPixmap(filesave_xpm));
     locContextMenu->addAction(storeHereAction);
     connect(storeHereAction, SIGNAL(triggered()), this, SLOT(mapStoreSignal()));
 
