@@ -4,7 +4,7 @@
  *
  * @section LICENSE
  *
- *      Copyright 2009 - 2013 <qmidiarp-devel@lists.sourceforge.net>
+ *      Copyright 2009 - 2014 <qmidiarp-devel@lists.sourceforge.net>
  *
  *      This program is free software; you can redistribute it and/or modify
  *      it under the terms of the GNU General Public License as published by
@@ -233,7 +233,7 @@ SeqWidget::SeqWidget(
     midiControl->addMidiLearnMenu("LoopMode", loopBox, 6);
 #endif
     QLabel *recordButtonLabel = new QLabel(tr("Re&cord"), seqBox);
-    recordAction = new QAction(QIcon(seqrecord_xpm), tr("Re&cord"), seqBox);
+    recordAction = new QAction(QPixmap(seqrecord_xpm), tr("Re&cord"), seqBox);
     recordAction->setToolTip(tr("Record step by step"));
     recordAction->setCheckable(true);
     QToolButton *recordButton = new QToolButton(seqBox);
